require 'omniauth-oauth2'

module OmniAuth
    module Strategies
        class Accounts9 < OmniAuth::Strategies::OAuth2
            option :name, 'accounts9'

            option :client_options, {:authorize_url => '/api/authorize',
                                     :token_url => '/api/access_token',
                                     :site => 'https://accounts.net9.org'}
            option :token_params, { :parse => :json }

            def request_phase
                super
            end

            def authorize_params
                super.tap do |params|
                    %w[scope client_options].each do |v|
                        if request.params[v]
                            params[v.to_sym] = request.params[v]
                        end
                    end
                end
            end

            uid { raw_info['uid'].to_s }

            info do
                {
                    :email => raw_info['email'],
                    :nickname => raw_info['name'],
                    :last_name => raw_info['surname'],
                    :first_name => raw_info['givenname'],
                    :name => raw_info['fullname'],
                    :location => raw_info['address'],
                    :description => raw_info['bio'],
                    :urls => {
                        'Website' => raw_info['website'],
                    }
                }
            end

            extra do
                {
                    :raw_info => raw_info
                }
            end

            def raw_info
                access_token.options[:mode] = :query
                access_token.options[:param_name] = 'access_token'
                @raw_info ||= access_token.get('https://accounts.net9.org/api/userinfo').parsed['user']
            end

            def callback_url	
                full_host + script_name + callback_path	
            end

        end
    end
end
